@@ -31,6 +31,7 @@ class Obraz(Mail_sender):
     self.obraz = self._set_obraz(obraz)
     self._wholebook = book 
     self.book = book
+    self.email = None
     self.model_chekpoint = model_chekpoint
     self.model = None
     self.tokenizer = None
@@ -107,7 +108,7 @@ class Obraz(Mail_sender):
         self._fast_book.append(text)
     self.book = self._fast_book
     print("В библиотеке ", i, " текстов, где есть хотя бы одно из буквосочетаний ", str(keys))
-    self._fast_print(keys, 'or')
+    self._fast_print(str(keys), 'or')
 
 
   def fast_and(self):
@@ -129,7 +130,7 @@ class Obraz(Mail_sender):
         self._fast_book.append(text)
     self.book = self._fast_book
     print("В библиотеке ", i, " текстов, где в каждом есть все буквосочетания ", str(keys))
-    self._fast_print(keys, 'and')
+    self._fast_print(str(keys), 'and')
   
 
   def results(self):
@@ -157,8 +158,9 @@ class Obraz(Mail_sender):
 
       self._wholebook = [sent[1:3] for sent in csv_book.values]
       for i in range(len(self._wholebook)):
-        re.sub(r'<.*?>(\s*.*?)</?.*?>', '', self._wholebook[i][0])
-        self._wholebook[i][0].strip()
+        self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
+        self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
+        self._wholebook[i][0] = self._wholebook[i][0].strip()
       self.book = self._wholebook
 
     elif adress_book != None:
@@ -166,8 +168,9 @@ class Obraz(Mail_sender):
 
       self._wholebook = [sent[1:3] for sent in csv_book.values]
       for i in range(len(self._wholebook)):
-        re.sub(r'<.*?>(\s*.*?)</?.*?>', '', self._wholebook[i][0])
-        self._wholebook[i][0].strip()
+        self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
+        self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
+        self._wholebook[i][0] = self._wholebook[i][0].strip()
       self.book = self._wholebook
       # print(self.book[:100])
 
@@ -175,13 +178,15 @@ class Obraz(Mail_sender):
     """
     Реализована возможность отправить результаты на почту. На вход электронный адрес.
     """
-    if email == None:
+    h_m_with_keykey = int(input("Сколько лучших результатов Вы хотите получить? Введите число: "))
+    if self.email != None:
+      email = self.email
+    elif email == None:
       # inp = input("Вы хотите получить лучшие результаты на почту в виде word файла? Введите Да или Нет: ")
       # if "нет".upper() in inp.upper():
       #   return 
       # if input("Хотите увидеть диаграмму распределения для текстов с ключевыми токенами? Введите 1 или 0 ") == "1":
       #   self.show_diagramm(self.texts_with_key_key)
-      h_m_with_keykey = int(input("Сколько лучших результатов Вы хотите получить? Введите число: "))
       print("Исходя из опыта, советуем Вам указать gmail. yandex или outlook тоже хорошо. mail - плохо. Не забудьте проверить спам!")
       email = input("Введите адрес Вашей электронной почты: ")
     if self.texts_with_key_key == None:
@@ -399,8 +404,11 @@ class Obraz(Mail_sender):
       for text in self._fast_book:
         print(text[0]+"    ("+text[1]+")", sep='')
     if choice == 2:
-      email = input("Введите ваш email: ")
-      self._send_to_email_docx_fast_book(keys=keys, mode=mode, email=email)
+      if self.email != None: 
+        email = self.email   
+      else:       
+        email = input("Введите ваш email: ")
+        self._send_to_email_docx_fast_book(keys=keys, mode=mode, email=email)
 
 
 
